using FitConnect.Models;
using FitConnect.Models.v1.Api;
using Route = FitConnect.Services.Models.v1.Routes.Route;

namespace FitConnect.Interfaces;

public interface ISender : IFitConnectClient {
    /// <summary>
    ///     Determines the destination id and configures the sender.
    /// </summary>
    /// <param name="leiaKey"></param>
    /// <param name="ags"></param>
    /// <param name="ars"></param>
    /// <param name="areaId"></param>
    /// <param name="receivedPublicKey">Callback for presenting the public key</param>
    /// <returns></returns>
    public Task<List<Route>> FindDestinationId(string leiaKey, string? ags = null,
        string? ars = null,
        string? areaId = null);

    /// <summary>
    ///     Sending a submission
    /// </summary>
    /// <param name="submission">
    ///     The submission to be sent. Use <see cref="SubmissionBuilder" /> to create
    ///     the submission
    /// </param>
    /// <returns></returns>
    Task<SentSubmission> SendAsync(SendableSubmission submission);

    /// <summary>
    ///     Sending a pre-encrypted submission
    /// </summary>
    /// <param name="submission">
    ///     The submission to be sent. Use <see cref="EncryptedSubmissionBuilder" />
    ///     to create the submission
    /// </param>
    /// <returns></returns>
    Task<SentSubmission> SendAsync(SendableEncryptedSubmission submission);

    /// <summary>
    ///     Receives the public key for the destination with the id <paramref name="destinationId" />
    /// </summary>
    /// <param name="destinationId">Destination id of the requested public key</param>
    /// <returns></returns>
    Task<string> GetPublicKeyForDestinationAsync(string destinationId);

    /// <summary>
    /// Requesting the state of the submission
    /// </summary>
    /// <returns></returns>
    Task<SubmissionState> GetStatusForSubmissionAsync(SentSubmission submission);
}
